=== modified file 'NEWS'
--- NEWS	2006-09-12 19:37:02 +0000
+++ NEWS	2006-09-13 01:52:31 +0000
@@ -81,7 +81,29 @@
     * WorkingTree.pending_merges is deprecated.  Please use the get_parent_ids
       (introduced in 0.10) method instead. (Robert Collins)
 
-bzr 0.10.0RC1  2006-08-28
+    * WorkingTree has a new lock_tree_write method which locks the branch for
+      read rather than write. This is appropriate for actions which only need
+      the branch data for reference rather than mutation. A new decorator
+      needs_tree_write_lock is provided in the workingtree module. Like the
+      needs_read_lock and needs_write_lock decorators this allows static 
+      declaration of the locking requirements of a function to ensure that
+      a lock is taken out for casual scripts. (Robert Collins)
+
+    * All WorkingTree methods which write to the tree, but not to the branch
+      have been converted to use ``needs_tree_write_lock`` rather than 
+      ``needs_write_lock``. Also converted is the revert, conflicts and tree
+      transform modules. This provides a modest performance improvement on 
+      metadir style trees, due to the reduce lock-acquisition, and a more
+      significant performance improvement on lightweight checkouts from 
+      remote branches, where trivial operations used to pay a significant 
+      penalty. It also provides the basis for allowing readonly checkouts.
+      (Robert Collins)
+
+    * Special case importing the standard library 'copy' module. This shaves
+      off 40ms of startup time, while retaining compatibility. See:
+      ``bzrlib/inspect_for_copy.py`` for more details. (John Arbash Meinel)
+
+bzr 0.10  2006-08-29
   
   IMPROVEMENTS:
     * 'merge' now takes --uncommitted, to apply uncommitted changes from a

=== modified file 'bzr'
--- bzr	2006-08-28 01:09:52 +0000
+++ bzr	2006-09-13 01:52:31 +0000
@@ -61,8 +61,6 @@
 
 try:
     import bzrlib
-    import bzrlib.commands
-    import bzrlib.trace
 except ImportError, e:
     sys.stderr.write("bzr: ERROR: "
                      "Couldn't import bzrlib and dependencies.\n"
@@ -70,6 +68,12 @@
                      "\n")
     raise
 
+import bzrlib.inspect_for_copy
+bzrlib.inspect_for_copy.import_copy_with_hacked_inspect()
+
+import bzrlib.commands
+import bzrlib.trace
+
 if bzrlib.version_info[:3] != (0, 11, 0):
     sys.stderr.write("bzr: WARNING: bzrlib version doesn't match the bzr program.\n"
             "This may indicate an installation problem.\n"

=== added file 'bzrlib/inspect_for_copy.py'
--- bzrlib/inspect_for_copy.py	1970-01-01 00:00:00 +0000
+++ bzrlib/inspect_for_copy.py	2006-09-13 01:52:31 +0000
@@ -0,0 +1,74 @@
+# Copyright (C) 2005, 2006 Canonical Development Ltd
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+
+"""A version of inspect that includes what 'copy' needs.
+
+Importing the python standard module 'copy' is far more expensive than it
+needs to be, because copy imports 'inspect' which imports 'tokenize'.
+And 'copy' only needs 2 small functions out of 'inspect', but has to
+load all of 'tokenize', which makes it horribly slow.
+
+This module is designed to use tricky hacks in import rules, to avoid this
+overhead.
+"""
+
+
+####
+# These are the only 2 functions that 'copy' needs from 'inspect'
+# As you can see, they are quite trivial, and don't justify the
+# 40ms spent to import 'inspect' because it is importing 'tokenize'
+# These are copied verbatim from the python standard library.
+
+# ----------------------------------------------------------- class helpers
+def _searchbases(cls, accum):
+    # Simulate the "classic class" search order.
+    if cls in accum:
+        return
+    accum.append(cls)
+    for base in cls.__bases__:
+        _searchbases(base, accum)
+
+
+def getmro(cls):
+    "Return tuple of base classes (including cls) in method resolution order."
+    if hasattr(cls, "__mro__"):
+        return cls.__mro__
+    else:
+        result = []
+        _searchbases(cls, result)
+        return tuple(result)
+
+
+def import_copy_with_hacked_inspect():
+    """Import the 'copy' module with a hacked 'inspect' module"""
+    # We don't actually care about 'getmro' but we need to pass
+    # something in the list so that we get the direct module,
+    # rather than getting the base module
+    import sys
+
+    # Don't hack around if 'inspect' already exists
+    if 'inspect' in sys.modules:
+        import copy
+        return
+
+    mod = __import__('bzrlib.inspect_for_copy',
+                     globals(), locals(), ['getmro'])
+
+    sys.modules['inspect'] = mod
+    try:
+        import copy
+    finally:
+        del sys.modules['inspect']

